/*jslint devel: true, node: true, bitwise: false, debug: false, eqeq: false,
evil: false, forin: false, newcap: false, nomen: false, plusplus: false,
regexp: false, sub: false, vars: false, undef: false, unused: false,
white: false, quotmark: single, indent: 2, maxlen: 80 */

/*global $, Alloy, alert, Ti, OS_ANDROID, OS_IOS, _, Backbone*/

'use strict';

// Monthly Payments - Fixed Rate Mortgage
exports.calculateMonthlyPayment = function (P, i, n)
{
  // M = Monthly Payment
  // P = Principal
  // i = Monthly Interest Rate
  // n = Number of Payments
  // mR = Monthly Interest
  // mR = (i /100) / 12
  // M = P * [(i * (1 + i)^n) / ((1 + i)^n - 1)]

  var iPlusOneToNFunction, M, mR = (i / 100) / 12;

  iPlusOneToNFunction = Math.pow(1 + mR, n);

  M = P * ((mR * iPlusOneToNFunction) /
    (iPlusOneToNFunction - 1));

  return Math.round(M * 100) / 100;
};

// Mortgage Balance
exports.calculateMortgageBalance = function (lA, iR, t, d) {
  //B = L[(1 + c)^n - (1 + c)^p]/[(1 + c)^n - 1]
  //B: mortgageBalance
  //lA: loan amount
  //iR: mortgage interest rate
  //t: mortgage term in years
  //d: duration in years of mortgage paid
  var power1, power2;

  //(1 + c)^n
  power1 = Math.pow(1 + iR / 1200, 12 * t);
  //(1 + c)^p
  power2 = Math.pow(1 + iR / 1200, 12 * d);

  //B = L[(1 + c)^n - (1 + c)^p]/[(1 + c)^n - 1]
  return (lA * ((power1 - power2) / (power1 - 1)));
};

// Property Tax
exports.calculatePropertyTax = function (l, ptr, a, n)
{
  // l = Loan Amount
  // ptr = Property Tax Rate
  // a = Appreciation Rate
  // n = Number of Years for Calculation

  var pTax, index, ttlpTax = 0, pTaxes = [];

  ptr = parseFloat(ptr / 100);
  a = parseFloat(a / 100);

  for (index = 0; index < n; index += 1)
  {
    pTax = l * ptr;
    ttlpTax += pTax;
    pTaxes.push(pTax);
    l += l * a;
  }

  return {
    totalPropertyTax: ttlpTax,
    propertyTaxes: pTaxes
  };
};

// Private Mortgage Insurance
exports.calculatePMI = function (p, pmi) {
  return (p * (pmi / 100) / 12);
};

// Private Mortgage Insurance Rate
exports.calculatePmiRate = function (rate) {
  // If the percent down is 0-4% then the PMI rate is 1.03 (0.0103%).
  if ((rate >= 0) && (rate <= 4)) {
    return 1.03;
  // If the percent down is 5-9% then the PMI rate is 0.875 (0.00875).
  } else if ((rate > 4) && (rate <= 9)) {
    return 0.875;
  // If the percent down is 10-14% then the PMI rate is 0.625 (0.00625%).
  } else if ((rate > 9) && (rate <= 14)) {
    return 0.625;
  // If the percent down is 15-19% then the PMI rate is 0.375 (0.00375%).
  } else if ((rate > 14) && (rate < 20)) {
    return 0.375;
  // for all other cases, set PMI to 0.
  } else {
    return 0;
  }
};

exports.undefinedToZero = function(i) {
  if (i == undefined) {
    return 0;
  } else {
    return i;
  }
}

//Loan Terms

exports.firstMonthlyPayment = function(J, P, N){
  // // P * ( J / (1 - (1 + J)^ -N))
  return P * ( J / (1 - Math.pow( (1 + J), -N ) ));
};

exports.monthlyInterestPaid = function(P, J){
  return P * J;
}

exports.monthlyPrinciplePayment = function(monthlyPayment, monthlyInterestPaid){
  return monthlyPayment - monthlyInterestPaid;
}

exports.loanBalance = function(P, monthlyPrincipalPaid){
  return P - monthlyPrincipalPaid;
}