var _ = require('underscore')._;
var index = Ti.UI.createWindow({
	backgroundColor: "white"
});
var container = Ti.UI.createView();
index.add(container);

var calculatorAttributes = {},
    c = require('Calculations'),
    f = require('Format'),
    v = require('Validate'),
    d = require('Display'),
    m = require('Modal');

(function () {

  calculatorAttributes =
    Ti.App.Properties.getObject('calculatorAttributes') || {};

  _.defaults(calculatorAttributes, {
    homePrice: 150000,
    downPaymentRate: 20,
    downPaymentRateCash: 30000,
    loanAmount: 120000,
    mortgageInterestRate: 4,
    term: 30,
    propertyTax: 1.2,
    homeownersInsuranceCost: 800,
    privateMortgageInsurance: 0
  });

  var amortization = [];

  var sections = [];
  var sectionsPre = [];
  var sectionsAft = [];
  var sectionsAftBk =[];

  var monthlyInterest = ( (calculatorAttributes.mortgageInterestRate / 12) / 100);
  var N = calculatorAttributes.term * 12;
  var O = N;
  var loanBalance = calculatorAttributes.loanAmount;

  var balanceTemplate = {
    childTemplates: [
      {
        type: 'Ti.UI.View',
        properties: {
          layout: 'horizontal',
          left: 10,
          right: 10,
          height: Ti.UI.SIZE
      },
      childTemplates: [
        {
          type: 'Ti.UI.Label',
          properties: {
            width: '50%',
            text: 'Balance',
            textAlign: Ti.UI.TEXT_ALIGNMENT_LEFT,
            font : {
              fontFamily: 'OpenSans',
              fontSize: 14
            }
          }
        },
        {
          type: 'Ti.UI.Label',
          bindId: 'yearBalance',
          properties: {
            width: '50%',
            textAlign: Ti.UI.TEXT_ALIGNMENT_RIGHT,
            font: {
              fontFamily: 'OpenSans',
              fontSize: 14
            }
          }
        }
        ]
      }
    ]
  };

  var listHeaderTemplate = {
    childTemplates: [
      {
        type: 'Ti.UI.View',
        properties: {
          layout: 'horizontal',
          height: Ti.UI.SIZE,
        },
        childTemplates: [
          {
            type: 'Ti.UI.Label',
            properties: {
              text: 'MONTH',
              width: '25%',
              textAlign: Ti.UI.TEXT_ALIGNMENT_CENTER,
              font: {
                fontFamily: 'OpenSans',
                fontSize: 9
              }
            }
          },
          {
            type: 'Ti.UI.Label',
            properties: {
              text: 'PRINCIPAL',
              width: '25%',
              textAlign: Ti.UI.TEXT_ALIGNMENT_CENTER,
              font: {
                fontFamily: 'OpenSans',
                fontSize: 9
              }
            }
          },
          {
            type: 'Ti.UI.Label',
            properties: {
              text: 'INTEREST',
              width: '25%',
              textAlign: Ti.UI.TEXT_ALIGNMENT_CENTER,
              font: {
                fontFamily: 'OpenSans',
                fontSize: 9
              }
            }
          },
          {
            type: 'Ti.UI.Label',
            properties: {
              text: 'BALANCE',
              width: '25%',
              textAlign: Ti.UI.TEXT_ALIGNMENT_CENTER,
              font: {
                fontFamily: 'OpenSans',
                fontSize: 9
              }
            }
          }
        ]
      }
    ]
  };

  var detailTemplate = {
    childTemplates: [
      {
        type: 'Ti.UI.View',
        properties: {
          layout: 'horizontal',
          left: 10,
          right: 10,
          height: Ti.UI.SIZE
      },
      childTemplates: [
        {
          type: 'Ti.UI.Label',
          properties: {
            width: Ti.UI.SIZE,
            text: 'Principal',
            textAlign: Ti.UI.TEXT_ALIGNMENT_LEFT,
            font : {
              fontFamily: 'OpenSans-Light',
              fontSize: 10
            }
          }
        },
        {
          type: 'Ti.UI.Label',
          bindId: 'yearPrincipal',
          properties: {
            width: Ti.UI.SIZE,
            textAlign: Ti.UI.TEXT_ALIGNMENT_RIGHT,
            left: 3,
            font: {
              fontFamily: 'OpenSans',
              fontSize: 10
            }
          }
        },
        {
          type: 'Ti.UI.Label',
          properties: {
            width: Ti.UI.SIZE,
            left: 12,
            text: 'Interest',
            textAlign: Ti.UI.TEXT_ALIGNMENT_LEFT,
            font : {
              fontFamily: 'OpenSans-Light',
              fontSize: 10
            }
          }
        },
        {
          type: 'Ti.UI.Label',
          bindId: 'yearInterest',
          properties: {
            width: Ti.UI.SIZE,
            textAlign: Ti.UI.TEXT_ALIGNMENT_RIGHT,
            left: 3,
            font: {
              fontFamily: 'OpenSans',
              fontSize: 10
            }
          }
        },
        {
          type: 'Ti.UI.Label',
          properties: {
            text: 'Show More',
            width: Ti.UI.FILL,
            textAlign: Ti.UI.TEXT_ALIGNMENT_RIGHT,
            font: {
              fontFamily: 'OpenSans',
              fontSize: 10
            }
          }
        }
        ]
      }
    ]
  };

  var listTemplate = {
    childTemplates: [
      {
        type: 'Ti.UI.View',
        properties: {
          layout: 'horizontal',
          left: 10,
          right: 10
        },
        childTemplates: [
          {
            type: 'Ti.UI.Label',
            bindId: 'month',
            properties: {
              width: '25%',
              textAlign: Ti.UI.TEXT_ALIGNMENT_CENTER,
              font: {
                fontFamily: 'OpenSans-Light',
                fontSize: 12
              }
            }
          },
          {
            type: 'Ti.UI.Label',
            bindId: 'interest',
            properties: {
              width: '25%',
              textAlign: Ti.UI.TEXT_ALIGNMENT_CENTER,
              font: {
                fontFamily: 'OpenSans-Light',
                fontSize: 12
              }
            }
          },
          {
            type: 'Ti.UI.Label',
            bindId: 'principle',
            properties: {
              width: '25%',
              textAlign: Ti.UI.TEXT_ALIGNMENT_CENTER,
              font: {
                fontFamily: 'OpenSans-Light',
                fontSize: 12
              }
            }
          },
          {
            type: 'Ti.UI.Label',
            bindId: 'balance',
            properties: {
              width: '25%',
              textAlign: Ti.UI.TEXT_ALIGNMENT_CENTER,
              font: {
                fontFamily: 'OpenSans-Light',
                fontSize: 12
              }
            }
          }
        ]
      }
    ]
  };

  var listView = Ti.UI.createListView({
    templates: {
      'main': listTemplate,
      'balance': balanceTemplate,
      'detail': detailTemplate,
      'header': listHeaderTemplate
    },
    defaultItemTemplate: 'main'
  });

  //monthly payments are a constant

  var monthlyPayment = c.firstMonthlyPayment(monthlyInterest, calculatorAttributes.loanAmount, N);

  for (i = 0; i < calculatorAttributes.term; i++) {

    var foo = [];
    var bar = [];

    var yearlyInterest = 0;
    var yearlyPrincipal = 0;

    for (j = 0; j < 12; j++) {
      
      //get end of month balance by 

      //Interest paid each month is the current loan balance * monthly interest
      var monthlyInterestPaid = loanBalance * monthlyInterest;
      yearlyInterest += monthlyInterestPaid;

      //Principal paid each month is the Monthly Payment - Monthly Interest Paid
      var monthlyPrinciplePaid = monthlyPayment - monthlyInterestPaid;
      yearlyPrincipal += monthlyPrinciplePaid;

      //Update current loan balance by subtracting the current balance by the monthly payment.
      loanBalance -= monthlyPrinciplePaid;

      foo.push([
        j + 1, //month
        monthlyPrinciplePaid,
        monthlyInterestPaid,
        loanBalance
      ]);

      bar.push({
        month: {text: (j + 1).toString()},
        principle: {text: f.dollars(f.addCommas(monthlyPrinciplePaid.toFixed(2)))},
        interest: {text: f.dollars(f.addCommas(monthlyInterestPaid.toFixed(2)))},
        balance: {text: f.dollars(f.addCommas(loanBalance.toFixed(2)))}
      });

    }

    bar.unshift({});
    bar.unshift({
      yearBalance: {text: f.dollars(f.addCommas(loanBalance.toFixed(2)))}
    });

    bar.push({
      yearPrincipal: {text: f.dollars(f.addCommas(yearlyPrincipal.toFixed(2)))},
      yearInterest: {text: f.dollars(f.addCommas(yearlyInterest.toFixed(2)))}
    });

    sectionsPre.push(bar);
    sections.push(foo);

  }

  sectionsPre.forEach(function(el, index){

    //for each section in sections pre, create a titanium section object and append to a sections array.
    // Ti.API.info(sectionsPre[index]);

    sectionsPre[index][0].template = "balance";
    sectionsPre[index][1].template = "header";
    sectionsPre[index][14].template = "detail";

    // Ti.API.info(sectionsPre[index]);

    var yearNameTemplate = Ti.UI.createView({
      backgroundColor: '#E9EAEE',
    });

    var yearName = Ti.UI.createLabel({
      text: f.yearName(index).toUpperCase(),
      color: '#666666',
      left: 0,
      height: 30,
      font: {
        fontSize: "10dip",
        fontFamily: "OpenSans-Bold"
      }
    });

    yearNameTemplate.add(yearName);

    sectionsAft.push(Ti.UI.createListSection({
      items: sectionsPre[index],
      headerView: yearNameTemplate
    }));

    sectionsAftBk.push(Ti.UI.createListSection({
      items: sectionsPre[index],
      headerView: yearNameTemplate
    }));

  });

  sectionsAft.forEach(function(el) {
    el.deleteItemsAt(1, 13);
  });

  sectionsAftBk.forEach(function(el ) {
    el.deleteItemsAt(0,1);
    el.deleteItemsAt(13,1);
  });
  
  var file = Ti.Filesystem.getFile(Ti.Filesystem.tempDirectory, 'tmp.json');
  file.write( sectionsAft );
  Ti.API.info(Ti.Filesystem.tempDirectory);



  listView.setSections(sectionsAft);

  container.add(listView);

  // removing/hiding the items in a listview.

  // Ti.API.info(listView.getSections());

  var lastSection;

  listView.addEventListener('itemclick', function(e){

    if ( typeof(lastSection) !== 'undefined' ) {

      var oldSection = sectionsAft[lastSection];
      listView.replaceSectionAt(lastSection, oldSection, false);

    }

    var newSection = sectionsAftBk[e.sectionIndex];
    listView.replaceSectionAt(e.sectionIndex, newSection, false);
    lastSection = e.sectionIndex;

  });

}());

index.open();
